netapp_ontap.resources.nis_service API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.nis_service`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

NIS servers are used to authenticate user and client computers. NIS domain name and NIS server information is required to configure NIS. It is important to note that this API is used to retrieve and manage NIS server configurations for data SVMs only. NIS configuration for the cluster is managed via `/api/security/authentication/cluster/nis`.

## Retrieving NIS Information

The NIS GET endpoint retrieves all of the NIS configurations for data SVMs.

## Examples

### Retrieving all fields for all NIS configurations

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(list(NisService.get_collection(fields="*")))

Try it out

    [
        NisService(
            {
                "servers": ["10.10.10.10", "example.com"],
                "_links": {
                    "self": {
                        "href": "/api/name-services/nis/179d3c85-7053-11e8-b9b8-005056b41bd1"
                    }
                },
                "svm": {
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/179d3c85-7053-11e8-b9b8-005056b41bd1"
                        }
                    },
                    "uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1",
                },
                "domain": "domainA.example.com",
            }
        ),
        NisService(
            {
                "servers": ["2.2.2.2", "3.3.3.3", "4.4.4.4"],
                "_links": {
                    "self": {
                        "href": "/api/name-services/nis/6a52023b-7066-11e8-b9b8-005056b41bd1"
                    }
                },
                "svm": {
                    "name": "vs2",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/6a52023b-7066-11e8-b9b8-005056b41bd1"
                        }
                    },
                    "uuid": "6a52023b-7066-11e8-b9b8-005056b41bd1",
                },
                "domain": "domainB.example.com",
            }
        ),
    ]

### Retrieving all NIS configurations whose bound servers start with 10

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NisService

    with HostConnection("<mgmt-ip", username="admin", password="password", verify=False):
        print(list(NisService.get_collection(bound_servers="10*")))

Try it out

    [
        NisService(
            {
                "_links": {
                    "self": {
                        "href": "/api/name-services/nis/6a52023b-7066-11e8-b9b8-005056b41bd1"
                    }
                },
                "svm": {
                    "name": "vs1",
                    "_links": {
                        "self": {
                            "href": "/api/svm/svms/179d3c85-7053-11e8-b9b8-005056b41bd1"
                        }
                    },
                    "uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1",
                },
            }
        )
    ]

### Retrieving the NIS configuration of a specific SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NisService(**{"svm.uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"})
        resource.get()
        print(resource)

Try it out

    NisService(
        {
            "servers": ["10.10.10.10", "example.com"],
            "svm": {"name": "vs1", "uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"},
            "bound_servers": ["10.10.10.10"],
            "domain": "domainA.example.com",
        }
    )

## Creating a NIS configuration

The NIS POST endpoint creates a NIS configuration for the specified SVM.

## Example

The following example shows a POST operation:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NisService()
        resource.svm = {"uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"}
        resource.domain = "domainA.example.com"
        resource.servers = ["10.10.10.10", "example.com"]
        resource.post(hydrate=True)
        print(resource)

## Updating the NIS configuration

The NIS PATCH endpoint updates the NIS configuration for the specified NIS server.

## Examples

### Updating the domain

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NisService(**{"svm.uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"})
        resource.domain = "domainC.example.com"
        resource.servers = ["13.13.13.13"]
        resource.patch()

### Updating the server

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NisService(**{"svm.uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"})
        resource.servers = ["14.14.14.14"]
        resource.patch()

## Deleting a NIS configuration

The NIS DELETE endpoint deletes the NIS configuration for the specified SVM.

## Example

## The following example shows a DELETE operation:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import NisService

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = NisService(**{"svm.uuid": "179d3c85-7053-11e8-b9b8-005056b41bd1"})
        resource.delete()

## Classes

`class NisService (*args, **kwargs)`

  Allows interaction with NisService objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all NisService resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('NisService')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes the NIS domain configuration of an SVM. NIS can be removed as a source from ns-switch if NIS is not used for lookups.

    ### Related ONTAP commands

    - `vserver services name-service nis-domain delete`

    ### Learn more

    - `DOC /name-services/nis`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent NisService resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves NIS domain configurations of all the SVMs. The bound_servers field indicates the successfully bound NIS servers. Lookups and authentications fail if there are no bound servers.

    ### Related ONTAP commands

    - `vserver services name-service nis-domain show`
    - `vserver services name-service nis-domain show-bound`
    - `vserver services name-service nis-domain show-bound-debug`

    ### Learn more

    - `DOC /name-services/nis`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves NIS domain configurations of all the SVMs. The bound_servers field indicates the successfully bound NIS servers. Lookups and authentications fail if there are no bound servers.

    ### Related ONTAP commands

    - `vserver services name-service nis-domain show`
    - `vserver services name-service nis-domain show-bound`
    - `vserver services name-service nis-domain show-bound-debug`

    ### Learn more

    - `DOC /name-services/nis`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('NisService')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates NIS domain and server configuration of an SVM.

    ### Important notes

    - Both NIS domain and servers can be modified.
    - Domains and servers cannot be empty.
    - Both FQDNs and IP addresses are supported for the servers field.
    - If the domain is modified, NIS servers must also be specified.
    - IPv6 must be enabled if IPv6 family addresses are specified for the servers field.

    ### Related ONTAP commands

    - `vserver services name-service nis-domain modify`

    ### Learn more

    - `DOC /name-services/nis`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('NisService')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[NisService], NetAppResponse]`

    Creates an NIS domain and server configuration for a data SVM. NIS configuration for the cluster is managed via `/api/security/authentication/cluster/nis`.

    ### Important notes

    - Each SVM can have one NIS domain configuration.
    - Multiple SVMs can be configured with the same NIS domain. Specify the NIS domain and NIS servers as input.Domain name and servers fields cannot be empty.
    - Both FQDNs and IP addresses are supported for the servers field.
    - IPv6 must be enabled if IPv6 family addresses are specified in the servers field.
    - A maximum of ten NIS servers are supported.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the NIS configuration.
    - `domain` - NIS domain to which the configuration belongs.
    - `servers` - List of NIS server IP addresses.

    ### Related ONTAP commands

    - `vserver services name-service nis-domain create`

    ### Learn more

    - `DOC /name-services/nis`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes the NIS domain configuration of an SVM. NIS can be removed as a source from ns-switch if NIS is not used for lookups.

    ### Related ONTAP commands

    - `vserver services name-service nis-domain delete`

    ### Learn more

    - `DOC /name-services/nis`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves NIS domain and server configurations of an SVM. Both NIS domain and servers are displayed by default. The bound_servers field indicates the successfully bound NIS servers.

    ### Related ONTAP commands

    - `vserver services name-service nis-domain show`
    - `vserver services name-service nis-domain show-bound`
    - `vserver services name-service nis-domain show-bound-debug`

    ### Learn more

    - `DOC /name-services/nis`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates NIS domain and server configuration of an SVM.

    ### Important notes

    - Both NIS domain and servers can be modified.
    - Domains and servers cannot be empty.
    - Both FQDNs and IP addresses are supported for the servers field.
    - If the domain is modified, NIS servers must also be specified.
    - IPv6 must be enabled if IPv6 family addresses are specified for the servers field.

    ### Related ONTAP commands

    - `vserver services name-service nis-domain modify`

    ### Learn more

    - `DOC /name-services/nis`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates an NIS domain and server configuration for a data SVM. NIS configuration for the cluster is managed via `/api/security/authentication/cluster/nis`.

    ### Important notes

    - Each SVM can have one NIS domain configuration.
    - Multiple SVMs can be configured with the same NIS domain. Specify the NIS domain and NIS servers as input.Domain name and servers fields cannot be empty.
    - Both FQDNs and IP addresses are supported for the servers field.
    - IPv6 must be enabled if IPv6 family addresses are specified in the servers field.
    - A maximum of ten NIS servers are supported.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the NIS configuration.
    - `domain` - NIS domain to which the configuration belongs.
    - `servers` - List of NIS server IP addresses.

    ### Related ONTAP commands

    - `vserver services name-service nis-domain create`

    ### Learn more

    - `DOC /name-services/nis`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class NisServiceSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NisService object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `binding_details: List[ClusterNisServiceBindingDetails] GET`

    An array of objects where each object represents the NIS server and it's status for a given NIS domain. It is an advanced field.

  `bound_servers: List[str] GET`

    The bound_servers field of the nis_service.

  `domain: str GET POST PATCH`

    The NIS domain to which this configuration belongs.

    Example: domainA.example.com

  `links: SelfLink GET`

    The links field of the nis_service.

  `servers: List[str] GET POST PATCH`

    A list of hostnames or IP addresses of NIS servers used by the NIS domain configuration.

    Example: ["10.10.10.10","example.com"]

  `svm: Svm GET POST`

    The svm field of the nis_service.